@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -62,6 +63,7 @@ static void destroy (GtkObject *object)
         (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 
     g_free (dialog->priv);
+    dialog->priv = NULL;
 }
 
 
@@ -117,7 +119,7 @@ static void init (GnomeCmdDialog *dialog)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_dialog_get_type (void)
+GtkType gnome_cmd_dialog_get_type ()
 {
     static GtkType dlg_type = 0;
 
