@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -229,7 +230,7 @@ create_category (GtkWidget *parent, GtkWidget *content, gchar *title)
 
 
 GtkWidget *
-create_named_button_with_data (GtkWidget *parent, gchar *label, gchar *name, GtkSignalFunc func, gpointer data)
+create_named_button_with_data (GtkWidget *parent, const gchar *label, const gchar *name, GtkSignalFunc func, gpointer data)
 {
     guint key;
     GtkAccelGroup *accel_group = gtk_accel_group_new ();
@@ -251,7 +252,7 @@ create_named_button_with_data (GtkWidget *parent, gchar *label, gchar *name, Gtk
 
 
 GtkWidget *
-create_button_with_data (GtkWidget *parent, gchar *label,
+create_button_with_data (GtkWidget *parent, const gchar *label,
                          GtkSignalFunc func, gpointer data)
 {
     return create_named_button_with_data (parent, label, "button", func, data);
@@ -308,7 +309,7 @@ create_stock_button (GtkWidget *parent, gconstpointer stock, GtkSignalFunc func)
 
 
 GtkWidget *
-create_entry (GtkWidget *parent, gchar *name, const gchar *value)
+create_entry (GtkWidget *parent, const gchar *name, const gchar *value)
 {
     GtkWidget *w = gtk_entry_new ();
     gtk_widget_ref (w);
@@ -337,7 +338,7 @@ create_check (GtkWidget *parent, gchar *text, gchar *name)
 
 
 GtkWidget *
-create_radio (GtkWidget *parent, GSList *group, gchar *text, gchar *name)
+create_radio (GtkWidget *parent, GSList *group, const gchar *text, const gchar *name)
 {
     GtkWidget *btn;
 
@@ -370,9 +371,9 @@ create_spin (GtkWidget *parent, gchar *name, gint min, gint max, gint value)
 
 
 GtkWidget *
-create_color_picker (GtkWidget *parent, gchar *name)
+create_color_button (GtkWidget *parent, gchar *name)
 {
-    GtkWidget *w = gnome_color_picker_new ();
+    GtkWidget *w = gtk_color_button_new ();
     gtk_widget_ref (w);
     gtk_object_set_data_full (GTK_OBJECT (parent), name, w,
                               (GtkDestroyNotify) gtk_widget_unref);
@@ -390,23 +391,11 @@ create_icon_entry (GtkWidget *parent, gchar *name, const gchar *icon_path)
                               (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (icon_entry);
     if (icon_path)
-        gnome_icon_entry_set_icon (GNOME_ICON_ENTRY (icon_entry), icon_path);
+        gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (icon_entry), icon_path);
     return icon_entry;
 }
 
 
-GtkWidget *
-create_font_picker (GtkWidget *parent, gchar *name)
-{
-    GtkWidget *w = gnome_font_picker_new ();
-    gtk_widget_ref (w);
-    gtk_object_set_data_full (GTK_OBJECT (parent), name, w,
-                              (GtkDestroyNotify) gtk_widget_unref);
-    gtk_widget_show (w);
-    return w;
-}
-
-
 GtkWidget *
 create_scale (GtkWidget *parent, gchar *name, gint value, gint min, gint max)
 {
