@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -76,15 +77,13 @@ struct _CvsPluginPrivate
 static GnomeCmdPluginClass *parent_class = NULL;
 
 
-static void
-on_dummy (GtkMenuItem *item, gpointer data)
+static void on_dummy (GtkMenuItem *item, gpointer data)
 {
     gnome_ok_dialog ("CVS plugin dummy operation");
 }
 
 
-static gboolean
-change_cwd (const gchar *fpath)
+static gboolean change_cwd (const gchar *fpath)
 {
     gchar *dir = g_path_get_dirname (fpath);
 
@@ -100,8 +99,7 @@ change_cwd (const gchar *fpath)
 }
 
 
-static void
-on_diff (GtkMenuItem *item, GnomeCmdState *state)
+static void on_diff (GtkMenuItem *item, GnomeCmdState *state)
 {
     GList *files = state->active_dir_selected_files;
     CvsPlugin *plugin = gtk_object_get_data (GTK_OBJECT (item), "plugin");
@@ -112,9 +110,8 @@ on_diff (GtkMenuItem *item, GnomeCmdState *state)
     for (; files; files = files->next)
     {
         gchar *cmd;
-        GnomeCmdFileInfo *finfo = GNOME_CMD_FILE_INFO (files->data);
-        GnomeVFSURI *uri = gnome_vfs_uri_append_file_name (
-            state->active_dir_uri, finfo->info->name);
+        GnomeCmdFileInfo *f = GNOME_CMD_FILE_INFO (files->data);
+        GnomeVFSURI *uri = gnome_vfs_uri_append_file_name (state->active_dir_uri, f->info->name);
         const gchar *fpath = gnome_vfs_uri_get_path (uri);
 
         change_cwd (fpath);
@@ -128,8 +125,7 @@ on_diff (GtkMenuItem *item, GnomeCmdState *state)
 }
 
 
-static void
-on_log (GtkMenuItem *item, GnomeCmdState *state)
+static void on_log (GtkMenuItem *item, GnomeCmdState *state)
 {
     GList *files = state->active_dir_selected_files;
     CvsPlugin *plugin = gtk_object_get_data (GTK_OBJECT (item), "plugin");
@@ -139,9 +135,8 @@ on_log (GtkMenuItem *item, GnomeCmdState *state)
 
     for (; files; files = files->next)
     {
-        GnomeCmdFileInfo *finfo = GNOME_CMD_FILE_INFO (files->data);
-        GnomeVFSURI *uri = gnome_vfs_uri_append_file_name (
-            state->active_dir_uri, finfo->info->name);
+        GnomeCmdFileInfo *f = GNOME_CMD_FILE_INFO (files->data);
+        GnomeVFSURI *uri = gnome_vfs_uri_append_file_name (state->active_dir_uri, f->info->name);
         const gchar *fpath = gnome_vfs_uri_get_path (uri);
 
         change_cwd (fpath);
@@ -150,18 +145,18 @@ on_log (GtkMenuItem *item, GnomeCmdState *state)
 }
 
 
-static GtkWidget *
-create_menu_item (const gchar *name, gboolean show_pixmap,
-                  GtkSignalFunc callback, gpointer data,
-                  CvsPlugin *plugin)
+static GtkWidget *create_menu_item (const gchar *name, gboolean show_pixmap,
+                                    GtkSignalFunc callback, gpointer data,
+                                    CvsPlugin *plugin)
 {
     GtkWidget *item, *label;
-    GtkWidget *pixmap = NULL;
 
     if (show_pixmap)
     {
+        GdkPixbuf *pixbuf = gdk_pixbuf_new_from_xpm_data ((const char **) cvs_plugin_xpm);
+        GtkWidget *pixmap = gtk_image_new_from_pixbuf (pixbuf);
+        g_object_unref (G_OBJECT (pixbuf));
         item = gtk_image_menu_item_new ();
-        pixmap = gnome_pixmap_new_from_xpm_d ((const gchar**)cvs_plugin_xpm);
         if (pixmap)
         {
             gtk_widget_show (pixmap);
@@ -173,13 +168,13 @@ create_menu_item (const gchar *name, gboolean show_pixmap,
 
     gtk_widget_show (item);
 
-    /* Create the contents of the menu item */
+    // Create the contents of the menu item
     label = gtk_label_new (name);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_widget_show (label);
     gtk_container_add (GTK_CONTAINER (item), label);
 
-    /* Connect to the signal and set user data */
+    // Connect to the signal and set user data
     gtk_object_set_data (GTK_OBJECT (item), GNOMEUIINFO_KEY_UIDATA, data);
 
     if (callback)
@@ -191,44 +186,36 @@ create_menu_item (const gchar *name, gboolean show_pixmap,
 }
 
 
-static GtkWidget *
-create_main_menu (GnomeCmdPlugin *p, GnomeCmdState *state)
+static GtkWidget *create_main_menu (GnomeCmdPlugin *p, GnomeCmdState *state)
 {
-    GtkWidget *item, *child;
     CvsPlugin *plugin = CVS_PLUGIN (p);
     GtkMenu *submenu = GTK_MENU (gtk_menu_new ());
 
-    item = create_menu_item ("CVS", FALSE, NULL, NULL, plugin);
+    GtkWidget *item = create_menu_item ("CVS", FALSE, NULL, NULL, plugin);
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), GTK_WIDGET (submenu));
 
-    plugin->priv->update = child =
-        create_menu_item ("Update", FALSE, GTK_SIGNAL_FUNC (on_dummy), state, plugin);
-    gtk_menu_append (submenu, child);
-    plugin->priv->diff = child =
-        create_menu_item ("Diff", FALSE, GTK_SIGNAL_FUNC (on_diff), state, plugin);
-    gtk_menu_append (submenu, child);
-    plugin->priv->log = child =
-        create_menu_item ("Log", FALSE, GTK_SIGNAL_FUNC (on_log), state, plugin);
-    gtk_menu_append (submenu, child);
-    plugin->priv->last_log = child =
-        create_menu_item ("Last Log", FALSE, GTK_SIGNAL_FUNC (on_dummy), state, plugin);
-    gtk_menu_append (submenu, child);
-    plugin->priv->last_change = child =
-        create_menu_item ("Last Change", FALSE, GTK_SIGNAL_FUNC (on_dummy), state, plugin);
-    gtk_menu_append (submenu, child);
+    plugin->priv->update = create_menu_item ("Update", FALSE, GTK_SIGNAL_FUNC (on_dummy), state, plugin);
+    gtk_menu_append (submenu, plugin->priv->update);
+    plugin->priv->diff = create_menu_item ("Diff", FALSE, GTK_SIGNAL_FUNC (on_diff), state, plugin);
+    gtk_menu_append (submenu, plugin->priv->diff);
+    plugin->priv->log = create_menu_item ("Log", FALSE, GTK_SIGNAL_FUNC (on_log), state, plugin);
+    gtk_menu_append (submenu, plugin->priv->log);
+    plugin->priv->last_log = create_menu_item ("Last Log", FALSE, GTK_SIGNAL_FUNC (on_dummy), state, plugin);
+    gtk_menu_append (submenu, plugin->priv->last_log);
+    plugin->priv->last_change = create_menu_item ("Last Change", FALSE, GTK_SIGNAL_FUNC (on_dummy), state, plugin);
+    gtk_menu_append (submenu, plugin->priv->last_change);
 
     return item;
 }
 
 
-static gboolean
-cvs_dir_exists (GList *files)
+static gboolean cvs_dir_exists (GList *files)
 {
     for (; files; files = files->next)
     {
-        GnomeCmdFileInfo *finfo = GNOME_CMD_FILE_INFO (files->data);
-        if (finfo->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY &&
-            strcmp (finfo->info->name, "CVS") == 0)
+        GnomeCmdFileInfo *f = GNOME_CMD_FILE_INFO (files->data);
+        if (f->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY &&
+            strcmp (f->info->name, "CVS") == 0)
         {
             return TRUE;
         }
@@ -238,8 +225,7 @@ cvs_dir_exists (GList *files)
 }
 
 
-static GList *
-create_popup_menu_items (GnomeCmdPlugin *plugin, GnomeCmdState *state)
+static GList *create_popup_menu_items (GnomeCmdPlugin *plugin, GnomeCmdState *state)
 {
     GtkWidget *item;
     GList *l = NULL;
@@ -256,35 +242,24 @@ create_popup_menu_items (GnomeCmdPlugin *plugin, GnomeCmdState *state)
 }
 
 
-static void
-update_main_menu_state (GnomeCmdPlugin *p, GnomeCmdState *state)
+static void update_main_menu_state (GnomeCmdPlugin *p, GnomeCmdState *state)
 {
     CvsPlugin *plugin = CVS_PLUGIN (p);
 
-    if (cvs_dir_exists (state->active_dir_files)) {
-        gtk_widget_set_sensitive (plugin->priv->update, TRUE);
-        gtk_widget_set_sensitive (plugin->priv->diff, TRUE);
-        gtk_widget_set_sensitive (plugin->priv->log, TRUE);
-        gtk_widget_set_sensitive (plugin->priv->last_log, TRUE);
-        gtk_widget_set_sensitive (plugin->priv->last_change, TRUE);
-    }
-    else {
-        gtk_widget_set_sensitive (plugin->priv->update, FALSE);
-        gtk_widget_set_sensitive (plugin->priv->diff, FALSE);
-        gtk_widget_set_sensitive (plugin->priv->log, FALSE);
-        gtk_widget_set_sensitive (plugin->priv->last_log, FALSE);
-        gtk_widget_set_sensitive (plugin->priv->last_change, FALSE);
-    }
+    gboolean dir_exists = cvs_dir_exists (state->active_dir_files);
+
+    gtk_widget_set_sensitive (plugin->priv->update, dir_exists);
+    gtk_widget_set_sensitive (plugin->priv->diff, dir_exists);
+    gtk_widget_set_sensitive (plugin->priv->log, dir_exists);
+    gtk_widget_set_sensitive (plugin->priv->last_log, dir_exists);
+    gtk_widget_set_sensitive (plugin->priv->last_change, dir_exists);
 }
 
 
-static void
-on_configure_close (GtkButton *btn, CvsPlugin *plugin)
+static void on_configure_close (GtkButton *btn, CvsPlugin *plugin)
 {
-    plugin->compression_level = gtk_option_menu_get_history (
-        GTK_OPTION_MENU (plugin->priv->compression_level_menu));
-    plugin->unidiff = gtk_toggle_button_get_active (
-        GTK_TOGGLE_BUTTON (plugin->priv->unidiff_check));
+    plugin->compression_level = gtk_option_menu_get_history (GTK_OPTION_MENU (plugin->priv->compression_level_menu));
+    plugin->unidiff = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (plugin->priv->unidiff_check));
 
     gnome_cmd_data_set_int ("/cvs-plugin/compression_level", plugin->compression_level);
 
@@ -292,8 +267,7 @@ on_configure_close (GtkButton *btn, CvsPlugin *plugin)
 }
 
 
-static void
-configure (GnomeCmdPlugin *p)
+static void configure (GnomeCmdPlugin *p)
 {
     GtkWidget *dialog, *table, *cat, *label, *vbox, *optmenu, *check;
     CvsPlugin *plugin = CVS_PLUGIN (p);
@@ -304,7 +278,7 @@ configure (GnomeCmdPlugin *p)
     gnome_cmd_dialog_set_transient_for (GNOME_CMD_DIALOG (dialog), GTK_WINDOW (main_win_widget));
     gnome_cmd_dialog_set_modal (GNOME_CMD_DIALOG (dialog));
 
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_OK,
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK,
                                  GTK_SIGNAL_FUNC (on_configure_close), plugin);
 
     vbox = create_vbox (dialog, FALSE, 12);
@@ -320,14 +294,12 @@ configure (GnomeCmdPlugin *p)
 
     optmenu = create_option_menu (dialog, compression_level_strings);
     plugin->priv->compression_level_menu = optmenu;
-    gtk_option_menu_set_history (GTK_OPTION_MENU (optmenu),
-                                 plugin->compression_level);
+    gtk_option_menu_set_history (GTK_OPTION_MENU (optmenu), plugin->compression_level);
     table_add (table, optmenu, 1, 1, GTK_FILL);
 
     check = create_check (dialog, _("Unified diff format"), "check");
     plugin->priv->unidiff_check = check;
-    gtk_toggle_button_set_active (
-        GTK_TOGGLE_BUTTON (check), plugin->unidiff);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), plugin->unidiff);
     gtk_table_attach (GTK_TABLE (table), check, 0, 2, 0, 1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
@@ -340,8 +312,7 @@ configure (GnomeCmdPlugin *p)
  * Gtk class implementation
  *******************************/
 
-static void
-destroy (GtkObject *object)
+static void destroy (GtkObject *object)
 {
     //CvsPlugin *plugin = CVS_PLUGIN (object);
 
@@ -350,8 +321,7 @@ destroy (GtkObject *object)
 }
 
 
-static void
-class_init (CvsPluginClass *klass)
+static void class_init (CvsPluginClass *klass)
 {
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GnomeCmdPluginClass *plugin_class = GNOME_CMD_PLUGIN_CLASS (klass);
@@ -367,10 +337,9 @@ class_init (CvsPluginClass *klass)
 }
 
 
-static void
-init (CvsPlugin *plugin)
+static void init (CvsPlugin *plugin)
 {
-    plugin->priv = g_new (CvsPluginPrivate, 1);
+    plugin->priv = g_new0 (CvsPluginPrivate, 1);
 
     plugin->diff_win = NULL;
     plugin->log_win = NULL;
@@ -385,8 +354,7 @@ init (CvsPlugin *plugin)
  * Public functions
  ***********************************/
 
-GtkType
-cvs_plugin_get_type         (void)
+GtkType cvs_plugin_get_type ()
 {
     static GtkType type = 0;
 
@@ -410,8 +378,7 @@ cvs_plugin_get_type         (void)
 }
 
 
-GnomeCmdPlugin *
-cvs_plugin_new (void)
+GnomeCmdPlugin *cvs_plugin_new ()
 {
     CvsPlugin *plugin = gtk_type_new (cvs_plugin_get_type ());
 
@@ -419,17 +386,17 @@ cvs_plugin_new (void)
 }
 
 
-GnomeCmdPlugin *create_plugin (void)
+GnomeCmdPlugin *create_plugin ()
 {
     return cvs_plugin_new ();
 }
 
 
-PluginInfo *get_plugin_info (void)
+PluginInfo *get_plugin_info ()
 {
     if (!plugin_nfo.authors)
     {
-        plugin_nfo.authors = g_new (gchar*, 2);
+        plugin_nfo.authors = g_new0 (gchar *, 2);
         plugin_nfo.authors[0] = AUTHOR;
         plugin_nfo.authors[1] = NULL;
         plugin_nfo.comments = g_strdup (_("A plugin that eventually will be a simple CVS client"));
