@@ -1,6 +1,7 @@
 /*
-    GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2004 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __FILTER_H__
@@ -22,34 +23,24 @@
 
 #include <regex.h>
 
-typedef enum {
-	FILTER_TYPE_REGEX,
-	FILTER_TYPE_FNMATCH
-} FilterType;
 
-
-typedef struct
+struct Filter
 {
-	/* common stuff */
-	FilterType type;
-	
-	/* regex filtering stuff */
-	regex_t *re_exp;
-	
-	/* fnmatch filtering stuff */
-	char *fn_exp;
-	int fn_flags;
-	
-} Filter;
+    enum Type
+    {
+        TYPE_REGEX,
+        TYPE_FNMATCH
+    };
 
+    Type type;          // common stuff
+    regex_t *re_exp;    // regex filtering stuff
+    char *fn_exp;       // fnmatch filtering stuff
+    int fn_flags;       // fnmatch filtering stuff
 
-Filter  *filter_new   (const gchar *exp,
-					   gboolean case_sens);
+    Filter(const gchar *exp, gboolean case_sens, Type type);
+    ~Filter();
 
-void     filter_free  (Filter *filter);
+    gboolean match(const gchar *text);
+};
 
-gboolean filter_match (Filter *filter,
-					   gchar *text);
-
-
-#endif //__FILTER_H__
+#endif // __FILTER_H__
