@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,10 +19,10 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-file.h"
-#include "gnome-cmd-dir-pool.h"
 #include "gnome-cmd-main-win.h"
 #include "gnome-cmd-con-smb.h"
 #include "gnome-cmd-data.h"
@@ -51,7 +52,7 @@ enum
     LAST_SIGNAL
 };
 
-struct _GnomeCmdDirPrivate
+struct GnomeCmdDirPrivate
 {
     GnomeVFSAsyncHandle *list_handle;
 
@@ -113,12 +114,10 @@ static void destroy (GtkObject *object)
 
     gnome_cmd_con_remove_from_cache (dir->priv->con, dir);
 
-    gtk_object_destroy (GTK_OBJECT (dir->priv->file_collection));
+    delete dir->priv->file_collection;
 
     if (dir->priv->path)
-        gtk_object_unref (GTK_OBJECT (dir->priv->path));
-
-    gnome_cmd_dir_pool_remove (gnome_cmd_con_get_dir_pool (dir->priv->con), dir);
+        g_object_unref (dir->priv->path);
 
     dir->priv->handle->ref = NULL;
     handle_unref (dir->priv->handle);
@@ -224,7 +223,7 @@ static void init (GnomeCmdDir *dir)
     dir->priv->monitor_handle = NULL;
     dir->priv->monitor_users = 0;
     dir->priv->files = NULL;
-    dir->priv->file_collection = gnome_cmd_file_collection_new ();
+    dir->priv->file_collection = new GnomeCmdFileCollection;
 }
 
 
@@ -232,7 +231,7 @@ static void init (GnomeCmdDir *dir)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_dir_get_type (void)
+GtkType gnome_cmd_dir_get_type ()
 {
     static GtkType type = 0;
 
@@ -406,22 +405,6 @@ Handle *gnome_cmd_dir_get_handle (GnomeCmdDir *dir)
 }
 
 
-void gnome_cmd_dir_ref (GnomeCmdDir *dir)
-{
-    g_return_if_fail (GNOME_CMD_IS_DIR (dir));
-
-    gnome_cmd_file_ref (GNOME_CMD_FILE (dir));
-}
-
-
-void gnome_cmd_dir_unref (GnomeCmdDir *dir)
-{
-    g_return_if_fail (GNOME_CMD_IS_DIR (dir));
-
-    gnome_cmd_file_unref (GNOME_CMD_FILE (dir));
-}
-
-
 GnomeVFSResult gnome_cmd_dir_get_files (GnomeCmdDir *dir, GList **files)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), GNOME_VFS_ERROR_BAD_PARAMETERS);
@@ -445,7 +428,6 @@ static GList *create_file_list (GnomeCmdDir *dir, GList *info_list)
 
         if (info && info->name)
         {
-            GnomeCmdFile *finfo;
             GnomeCmdCon *con = gnome_cmd_dir_get_connection (dir);
 
             if (strcmp (info->name, ".") == 0 || strcmp (info->name, "..") == 0)
@@ -470,11 +452,11 @@ static GList *create_file_list (GnomeCmdDir *dir, GList *info_list)
                                                                      g_strdup ("x-directory/smb-server");
             }
 
-            finfo = info->type == GNOME_VFS_FILE_TYPE_DIRECTORY ? GNOME_CMD_FILE (gnome_cmd_dir_new_from_info (info, dir)) :
-                                                                  gnome_cmd_file_new (info, dir);
+            GnomeCmdFile *f = info->type == GNOME_VFS_FILE_TYPE_DIRECTORY ? GNOME_CMD_FILE (gnome_cmd_dir_new_from_info (info, dir)) :
+                                                                            gnome_cmd_file_new (info, dir);
 
-            gnome_cmd_file_ref (finfo);
-            file_list = g_list_append (file_list, finfo);
+            gnome_cmd_file_ref (f);
+            file_list = g_list_append (file_list, f);
         }
     }
 
@@ -488,11 +470,11 @@ static void on_list_done (GnomeCmdDir *dir, GList *infolist, GnomeVFSResult resu
     {
         DEBUG('l', "File listing succeded\n");
 
-        if (gnome_cmd_file_collection_get_size (dir->priv->file_collection))
-            gnome_cmd_file_collection_clear (dir->priv->file_collection);
+        if (!dir->priv->file_collection->empty())
+            dir->priv->file_collection->clear();
 
         dir->priv->files = create_file_list (dir, infolist);
-        gnome_cmd_file_collection_add_list (dir->priv->file_collection, dir->priv->files);
+        dir->priv->file_collection->add(dir->priv->files);
         dir->state = DIR_STATE_LISTED;
         g_list_free (infolist);
 
@@ -546,7 +528,7 @@ static void create_list_progress_dialog (GnomeCmdDir *dir)
 
     gnome_cmd_dialog_add_button (
         GNOME_CMD_DIALOG (dir->dialog),
-        GNOME_STOCK_BUTTON_CANCEL,
+        GTK_STOCK_CANCEL,
         GTK_SIGNAL_FUNC (on_dir_list_cancel), dir);
 
     GtkWidget *vbox = create_vbox (dir->dialog, FALSE, 0);
@@ -725,19 +707,16 @@ GnomeVFSURI *gnome_cmd_dir_get_absolute_path_uri (GnomeCmdDir *dir, string absol
 }
 
 
-static gboolean file_already_exists (GnomeCmdDir *dir, const gchar *uri_str)
+inline gboolean file_already_exists (GnomeCmdDir *dir, const gchar *uri_str)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), TRUE);
     g_return_val_if_fail (uri_str != NULL, TRUE);
 
-    GnomeCmdFile *finfo = gnome_cmd_file_collection_lookup (dir->priv->file_collection, uri_str);
-
-    return finfo != NULL;
+    return dir->priv->file_collection->find(uri_str) != NULL;
 }
 
 
-/* A file has been created. Create a new GnomeCmdFile object for that file
- */
+// A file has been created. Create a new GnomeCmdFile object for that file
 void gnome_cmd_dir_file_created (GnomeCmdDir *dir, const gchar *uri_str)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
@@ -752,74 +731,71 @@ void gnome_cmd_dir_file_created (GnomeCmdDir *dir, const gchar *uri_str)
     GnomeVFSResult res = gnome_vfs_get_file_info_uri (uri, info, infoOpts);
     gnome_vfs_uri_unref (uri);
 
-    GnomeCmdFile *finfo;
+    GnomeCmdFile *f;
 
     if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
-        finfo = GNOME_CMD_FILE (gnome_cmd_dir_new_from_info (info, dir));
+        f = GNOME_CMD_FILE (gnome_cmd_dir_new_from_info (info, dir));
     else
-        finfo = gnome_cmd_file_new (info, dir);
+        f = gnome_cmd_file_new (info, dir);
 
-    gnome_cmd_file_collection_add (dir->priv->file_collection, finfo);
-    dir->priv->files = gnome_cmd_file_collection_get_list (dir->priv->file_collection);
+    dir->priv->file_collection->add(f);
+    dir->priv->files = dir->priv->file_collection->get_list();
 
-    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_CREATED], finfo);
+    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_CREATED], f);
 }
 
 
-/* A file has been deleted. Remove the corresponding GnomeCmdFile
- */
+// A file has been deleted. Remove the corresponding GnomeCmdFile
 void gnome_cmd_dir_file_deleted (GnomeCmdDir *dir, const gchar *uri_str)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
     g_return_if_fail (uri_str != NULL);
 
-    GnomeCmdFile *finfo = gnome_cmd_file_collection_lookup (dir->priv->file_collection, uri_str);
+    GnomeCmdFile *f = dir->priv->file_collection->find(uri_str);
 
-    if (!GNOME_CMD_IS_FILE (finfo))
+    if (!GNOME_CMD_IS_FILE (f))
         return;
 
-    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_DELETED], finfo);
+    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_DELETED], f);
 
-    gnome_cmd_file_collection_remove_by_uri (dir->priv->file_collection, uri_str);
-    dir->priv->files = gnome_cmd_file_collection_get_list (dir->priv->file_collection);
+    dir->priv->file_collection->remove(uri_str);
+    dir->priv->files = dir->priv->file_collection->get_list();
 }
 
 
-/* A file has been changed. Find the corresponding GnomeCmdFile, update its
- * GnomeVFSFileInfo
- */
+// A file has been changed. Find the corresponding GnomeCmdFile, update its GnomeVFSFileInfo
 void gnome_cmd_dir_file_changed (GnomeCmdDir *dir, const gchar *uri_str)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
     g_return_if_fail (uri_str != NULL);
 
-    GnomeVFSFileInfoOptions infoOpts = GNOME_VFS_FILE_INFO_GET_MIME_TYPE;
-    GnomeCmdFile *finfo = gnome_cmd_file_collection_lookup (dir->priv->file_collection, uri_str);
+    GnomeCmdFile *f = dir->priv->file_collection->find(uri_str);
 
-    g_return_if_fail (GNOME_CMD_IS_FILE (finfo));
+    g_return_if_fail (GNOME_CMD_IS_FILE (f));
 
-    GnomeVFSURI *uri = gnome_cmd_file_get_uri (finfo);
+    GnomeVFSURI *uri = gnome_cmd_file_get_uri (f);
     GnomeVFSFileInfo *info = gnome_vfs_file_info_new ();
-    GnomeVFSResult res = gnome_vfs_get_file_info_uri (uri, info, infoOpts);
+    GnomeVFSResult res = gnome_vfs_get_file_info_uri (uri, info, GNOME_VFS_FILE_INFO_GET_MIME_TYPE);
     gnome_vfs_uri_unref (uri);
 
-    gnome_cmd_file_update_info (finfo, info);
-    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_CHANGED], finfo);
+    gnome_cmd_file_update_info (f, info);
+    gnome_cmd_file_invalidate_metadata (f);
+    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_CHANGED], f);
 }
 
 
-void gnome_cmd_dir_file_renamed (GnomeCmdDir *dir, GnomeCmdFile *finfo, const gchar *old_uri_str)
+void gnome_cmd_dir_file_renamed (GnomeCmdDir *dir, GnomeCmdFile *f, const gchar *old_uri_str)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
-    g_return_if_fail (GNOME_CMD_IS_FILE (finfo));
+    g_return_if_fail (GNOME_CMD_IS_FILE (f));
     g_return_if_fail (old_uri_str!=NULL);
 
-    if (GNOME_CMD_IS_DIR (finfo))
+    if (GNOME_CMD_IS_DIR (f))
         gnome_cmd_con_remove_from_cache (dir->priv->con, old_uri_str);
 
-    gnome_cmd_file_collection_remove_by_uri (dir->priv->file_collection, old_uri_str);
-    gnome_cmd_file_collection_add (dir->priv->file_collection, finfo);
-    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_RENAMED], finfo);
+    dir->priv->file_collection->remove(old_uri_str);
+    dir->priv->file_collection->add(f);
+    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_RENAMED], f);
 }
 
 
@@ -845,7 +821,7 @@ void gnome_cmd_dir_start_monitoring (GnomeCmdDir *dir)
             &dir->priv->monitor_handle,
             uri_str,
             GNOME_VFS_MONITOR_DIRECTORY,
-            (GnomeVFSMonitorCallback)monitor_callback,
+            (GnomeVFSMonitorCallback) monitor_callback,
             dir);
 
         if (result == GNOME_VFS_OK)
