@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,8 +22,6 @@
 
 #include "gnome-cmd-path.h"
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_PLAIN_PATH(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_plain_path_get_type (), GnomeCmdPlainPath)
 #define GNOME_CMD_PLAIN_PATH_CLASS(klass) \
@@ -31,34 +30,26 @@ G_BEGIN_DECLS
     GTK_CHECK_TYPE (obj, gnome_cmd_plain_path_get_type ())
 
 
-typedef struct _GnomeCmdPlainPath GnomeCmdPlainPath;
-typedef struct _GnomeCmdPlainPathClass GnomeCmdPlainPathClass;
-typedef struct _GnomeCmdPlainPathPrivate GnomeCmdPlainPathPrivate;
+struct GnomeCmdPlainPathPrivate;
 
 
-struct _GnomeCmdPlainPath
+struct GnomeCmdPlainPath
 {
     GnomeCmdPath parent;
 
     GnomeCmdPlainPathPrivate *priv;
 };
 
-struct _GnomeCmdPlainPathClass
+struct GnomeCmdPlainPathClass
 {
     GnomeCmdPathClass parent_class;
 
-    void (* update_text)  (GtkEditable    *editable,
-                           gint            start_pos,
-                           gint            end_pos);
+    void (* update_text) (GtkEditable *editable, gint start_pos, gint end_pos);
 };
 
 
-GtkType
-gnome_cmd_plain_path_get_type (void);
+GtkType gnome_cmd_plain_path_get_type ();
 
-GnomeCmdPath *
-gnome_cmd_plain_path_new (const gchar *path);
-
-G_END_DECLS
+GnomeCmdPath *gnome_cmd_plain_path_new (const gchar *path);
 
 #endif // __GNOME_CMD_PLAIN_PATH_H__
