@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-prepare-copy-dialog.h"
 #include "gnome-cmd-prepare-xfer-dialog.h"
@@ -57,10 +59,12 @@ static void on_ok (GtkButton *button, gpointer user_data)
         else
             dlg->xferOverwriteMode = GNOME_VFS_XFER_OVERWRITE_MODE_SKIP;
 
-    dlg->xferOptions = GNOME_VFS_XFER_RECURSIVE;
+    guint xferOptions = GNOME_VFS_XFER_RECURSIVE;
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->follow_links)))
-        (int &) (dlg->xferOptions) |= GNOME_VFS_XFER_FOLLOW_LINKS;
+        xferOptions |= GNOME_VFS_XFER_FOLLOW_LINKS;
+
+    dlg->xferOptions = (GnomeVFSXferOptions) xferOptions;
 }
 
 
@@ -71,11 +75,9 @@ void gnome_cmd_prepare_copy_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFil
 
     GSList *group = NULL;
     PrepareCopyData *data = g_new0 (PrepareCopyData, 1);
-    GnomeCmdFile *finfo;
-    gint num_files;
     gchar *dest_dir_frame_msg, *text;
     GtkWidget *label;
-    GList *tmp = gnome_cmd_file_list_get_selected_files (from->list);
+    GList *tmp = from->file_list()->get_selected_files();
 
     if (!tmp)
     {
@@ -88,9 +90,8 @@ void gnome_cmd_prepare_copy_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFil
     gtk_widget_ref (GTK_WIDGET (data->dialog));
 
 
-    /*
-     * Create prepare copy specific widgets
-     */
+    // Create prepare copy specific widgets
+
     data->silent = gtk_radio_button_new_with_label (group, _("Silently"));
     group = gtk_radio_button_group (GTK_RADIO_BUTTON (data->silent));
     gtk_widget_ref (data->silent);
@@ -112,7 +113,7 @@ void gnome_cmd_prepare_copy_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFil
     gtk_widget_show (data->skip);
     gtk_box_pack_start (GTK_BOX (data->dialog->left_vbox), data->skip, FALSE, FALSE, 0);
 
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (g_slist_nth_data (group, gnome_cmd_data_get_confirm_overwrite_copy ())), TRUE);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (g_slist_nth_data (group, gnome_cmd_data.confirm_copy_overwrite)), TRUE);
 
 
     data->follow_links = gtk_check_button_new_with_label (_("Follow Links"));
@@ -122,9 +123,8 @@ void gnome_cmd_prepare_copy_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFil
     gtk_box_pack_start (GTK_BOX (data->dialog->right_vbox), data->follow_links, FALSE, FALSE, 0);
 
 
-    /*
-     * Customize prepare xfer widgets
-     */
+    // Customize prepare xfer widgets
+
     text = get_bold_text (_("Overwrite Files"));
     label = (GtkWidget *) gtk_object_get_data (GTK_OBJECT (data->dialog->left_vbox_frame), "label");
     gtk_label_set_markup (GTK_LABEL (label), text);
@@ -137,12 +137,12 @@ void gnome_cmd_prepare_copy_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFil
 
     g_return_if_fail (data->dialog->src_files != NULL);
 
-    num_files = g_list_length (data->dialog->src_files);
-    finfo = (GnomeCmdFile *) data->dialog->src_files->data;
+    gint num_files = g_list_length (data->dialog->src_files);
 
     if (num_files == 1)
     {
-        gchar *fname = get_utf8 (finfo->info->name);
+        GnomeCmdFile *f = (GnomeCmdFile *) data->dialog->src_files->data;
+        gchar *fname = get_utf8 (f->info->name);
         dest_dir_frame_msg = g_strdup_printf (_("Copy \"%s\" to"), fname);
         g_free (fname);
     }
@@ -157,14 +157,12 @@ void gnome_cmd_prepare_copy_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFil
     g_free (dest_dir_frame_msg);
 
 
-    /*
-     * Connect signals
-     */
+    // Connect signals
+
     gtk_signal_connect (GTK_OBJECT (data->dialog->ok_button), "clicked", GTK_SIGNAL_FUNC (on_ok), data);
 
 
-    /*
-     * Show the dialog
-     */
+    // Show the dialog
+
     gtk_widget_show (GTK_WIDGET (data->dialog));
 }
