@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,6 +20,7 @@
 
 #include <config.h>
 #include <unistd.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-xfer.h"
 #include "gnome-cmd-file-selector.h"
@@ -60,9 +62,9 @@ typedef struct
     gboolean first_time;
     gchar *cur_file_name;
 
-    GnomeVFSFileSize bytes_total;
     GnomeVFSFileSize file_size;
     GnomeVFSFileSize bytes_copied;
+    GnomeVFSFileSize bytes_total;
     GnomeVFSFileSize total_bytes_copied;
 
     GFunc on_completed_func;
@@ -74,18 +76,15 @@ typedef struct
 } XferData;
 
 
-static void
-free_xfer_data (XferData *data)
+inline void free_xfer_data (XferData *data)
 {
-    GList *tmp_list;
-
     if (data->on_completed_func)
         data->on_completed_func (data->on_completed_data, NULL);
 
     g_list_free (data->src_uri_list);
 
     //  free the list with target uris
-    for (tmp_list = data->dest_uri_list; tmp_list; tmp_list = tmp_list->next)
+    for (GList *tmp_list = data->dest_uri_list; tmp_list; tmp_list = tmp_list->next)
     {
         GnomeVFSURI *uri = (GnomeVFSURI *) tmp_list->data;
         gnome_vfs_uri_unref (uri);
@@ -128,17 +127,13 @@ create_xfer_data (GnomeVFSXferOptions xferOptions, GList *src_uri_list, GList *d
 }
 
 
-static gint
-xfer_callback (GnomeVFSXferProgressInfo *info, gpointer user_data)
+static gint xfer_callback (GnomeVFSXferProgressInfo *info, gpointer user_data)
 {
     return 1;
 }
 
 
-static gint
-async_xfer_callback (GnomeVFSAsyncHandle *handle,
-                     GnomeVFSXferProgressInfo *info,
-                     XferData *data)
+static gint async_xfer_callback (GnomeVFSAsyncHandle *handle, GnomeVFSXferProgressInfo *info, XferData *data)
 {
     data->cur_phase = info->phase;
     data->cur_file = info->file_index;
@@ -165,7 +160,8 @@ async_xfer_callback (GnomeVFSAsyncHandle *handle,
 
     if (info->status == GNOME_VFS_XFER_PROGRESS_STATUS_OVERWRITE)
     {
-        gchar *t = gnome_vfs_get_local_path_from_uri (info->target_name);
+        gchar *t = gnome_cmd_dir_is_local (data->to_dir) ? gnome_vfs_get_local_path_from_uri (info->target_name) :
+                                                           str_uri_basename (info->target_name);
         gchar *fn = get_utf8 (t);
         gchar *msg = g_strdup_printf (_("The file \"%s\" already exists.\n\nDo you want to overwrite it?\n"), fn);
 
@@ -184,7 +180,8 @@ async_xfer_callback (GnomeVFSAsyncHandle *handle,
             && data->prev_status != GNOME_VFS_XFER_PROGRESS_STATUS_OVERWRITE)
         {
             const gchar *error = gnome_vfs_result_to_string (info->vfs_status);
-            gchar *t = gnome_vfs_get_local_path_from_uri (info->target_name);
+            gchar *t = gnome_cmd_dir_is_local (data->to_dir) ? gnome_vfs_get_local_path_from_uri (info->target_name) :
+                                                               str_uri_basename (info->target_name);
             gchar *fn = get_utf8 (t);
             gchar *msg = g_strdup_printf (_("Error while copying to %s\n\n%s"), fn, error);
 
@@ -211,8 +208,7 @@ async_xfer_callback (GnomeVFSAsyncHandle *handle,
 }
 
 
-static gboolean
-update_xfer_gui_func (XferData *data)
+static gboolean update_xfer_gui_func (XferData *data)
 {
     if (data->win && data->win->cancel_pressed)
     {
@@ -256,7 +252,7 @@ update_xfer_gui_func (XferData *data)
             if ((total_diff > (gfloat)0.01 && total_prog >= 0.0 && total_prog <= 1.0) || data->first_time)
             {
                 data->first_time = FALSE;
-                gnome_cmd_xfer_progress_win_set_total_progress (data->win, data->total_bytes_copied, data->bytes_total);
+                gnome_cmd_xfer_progress_win_set_total_progress (data->win, data->bytes_copied, data->file_size, data->total_bytes_copied, data->bytes_total);
                 while (gtk_events_pending ())
                     gtk_main_iteration_do (FALSE);
             }
@@ -265,10 +261,30 @@ update_xfer_gui_func (XferData *data)
 
     if (data->done)
     {
-        // Remove files from the source file-list when a move operation has finished
+        // Remove files from the source file list when a move operation has finished
         if (data->xferOptions & GNOME_VFS_XFER_REMOVESOURCE)
             if (data->src_fl && data->src_files)
-                gnome_cmd_file_list_remove_files (data->src_fl, data->src_files);
+            {
+                /**********************************************************************
+
+                    previous function used here:
+                    gnome_cmd_file_list_remove_files (data->src_fl, data->src_files);
+
+                    After 'async_xfer_callback' has been called the file list, 'src_files' has
+                    not been altered and source files that have moved might be write protected.
+                    So we need to check if files that are to be removed from the file list
+                    still exist.
+
+                *************************************************************************/
+
+                for (; data->src_files; data->src_files = data->src_files->next)
+                {
+                    GnomeVFSURI *src_uri = gnome_cmd_file_get_uri ((GnomeCmdFile *) data->src_files->data);
+                    if (!gnome_vfs_uri_exists (src_uri))
+                        data->src_fl->remove_file((GnomeCmdFile *) data->src_files->data);
+                    g_free (src_uri);
+                }
+            }
 
         //  Only update the files if needed
         if (data->to_dir)
@@ -296,20 +312,15 @@ update_xfer_gui_func (XferData *data)
 }
 
 
-static gboolean
-uri_is_parent_to_dir_or_equal (GnomeVFSURI *uri, GnomeCmdDir *dir)
+inline gboolean uri_is_parent_to_dir_or_equal (GnomeVFSURI *uri, GnomeCmdDir *dir)
 {
-    GnomeVFSURI *dir_uri;
-    gboolean is_parent, is_equal;
-    char *uri_str, *dir_uri_str;
+    GnomeVFSURI *dir_uri = gnome_cmd_file_get_uri (GNOME_CMD_FILE (dir));
 
-    dir_uri = gnome_cmd_file_get_uri (GNOME_CMD_FILE (dir));
+    gboolean is_parent = gnome_vfs_uri_is_parent (uri, dir_uri, TRUE);
 
-    is_parent = gnome_vfs_uri_is_parent (uri, dir_uri, TRUE);
-
-    uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
-    dir_uri_str = gnome_vfs_uri_to_string (dir_uri, GNOME_VFS_URI_HIDE_NONE);
-    is_equal = gnome_vfs_uris_match (uri_str, dir_uri_str);
+    gchar *uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+    gchar *dir_uri_str = gnome_vfs_uri_to_string (dir_uri, GNOME_VFS_URI_HIDE_NONE);
+    gboolean is_equal = gnome_vfs_uris_match (uri_str, dir_uri_str);
 
     g_free (uri_str);
     g_free (dir_uri_str);
@@ -319,13 +330,11 @@ uri_is_parent_to_dir_or_equal (GnomeVFSURI *uri, GnomeCmdDir *dir)
 }
 
 
-static gchar *
-remove_basename (gchar *in)
+inline gchar *remove_basename (gchar *in)
 {
-    gint i;
     gchar *out = g_strdup (in);
 
-    for (i=strlen(out)-1; i>0; i--)
+    for (gint i=strlen(out)-1; i>0; i--)
         if (out[i] == '/')
         {
             out[i] = '\0';
@@ -336,8 +345,7 @@ remove_basename (gchar *in)
 }
 
 
-static gboolean
-file_is_already_in_dir (GnomeVFSURI *uri, GnomeCmdDir *dir)
+inline gboolean file_is_already_in_dir (GnomeVFSURI *uri, GnomeCmdDir *dir)
 {
     gchar *tmp = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
     gchar *uri_str = remove_basename (tmp);
@@ -368,13 +376,8 @@ gnome_cmd_xfer_uris_start (GList *src_uri_list,
     g_return_if_fail (GNOME_CMD_IS_DIR (to_dir));
 
     GnomeVFSURI *src_uri, *dest_uri;
-    GnomeVFSResult result;
-    gint num_files;
-    XferData *data;
 
-    /*
-     * Sanity check
-     */
+    // Sanity check
     for (GList *tmp = src_uri_list; tmp; tmp = tmp->next)
     {
         src_uri = (GnomeVFSURI *) tmp->data;
@@ -391,14 +394,13 @@ gnome_cmd_xfer_uris_start (GList *src_uri_list,
             }
     }
 
-    data = create_xfer_data (
-        xferOptions, src_uri_list, NULL,
-        to_dir, src_fl, src_files,
-        (GFunc)on_completed_func, on_completed_data);
+    XferData *data = create_xfer_data (xferOptions, src_uri_list, NULL,
+                                       to_dir, src_fl, src_files,
+                                       (GFunc) on_completed_func, on_completed_data);
 
-    num_files = g_list_length (src_uri_list);
+    gint num_files = g_list_length (src_uri_list);
 
-    if (g_list_length (src_uri_list) == 1 && dest_fn != NULL)
+    if (num_files == 1 && dest_fn != NULL)
     {
         dest_uri = gnome_cmd_dir_get_child_uri (to_dir, dest_fn);
 
@@ -409,7 +411,7 @@ gnome_cmd_xfer_uris_start (GList *src_uri_list,
         for (; src_uri_list; src_uri_list = src_uri_list->next)
         {
             src_uri = (GnomeVFSURI *) src_uri_list->data;
-            gchar *basename = gnome_vfs_unescape_string (gnome_vfs_uri_extract_short_name (src_uri), 0);
+            gchar *basename = gnome_vfs_uri_extract_short_name (src_uri);
 
             dest_uri = gnome_cmd_dir_get_child_uri (to_dir, basename);
             g_free (basename);
@@ -420,25 +422,25 @@ gnome_cmd_xfer_uris_start (GList *src_uri_list,
 
     g_free (dest_fn);
 
-    data->win = GNOME_CMD_XFER_PROGRESS_WIN (gnome_cmd_xfer_progress_win_new ());
+    data->win = GNOME_CMD_XFER_PROGRESS_WIN (gnome_cmd_xfer_progress_win_new (num_files));
     gtk_widget_ref (GTK_WIDGET (data->win));
     gtk_window_set_title (GTK_WINDOW (data->win), _("preparing..."));
     gtk_widget_show (GTK_WIDGET (data->win));
 
     //  start the transfer
-    result = gnome_vfs_async_xfer (&data->handle,
-                                   data->src_uri_list,
-                                   data->dest_uri_list,
-                                   xferOptions,
-                                   GNOME_VFS_XFER_ERROR_MODE_QUERY,
-                                   xferOverwriteMode,
-                                   XFER_PRIORITY,
-                                   (GnomeVFSAsyncXferProgressCallback)async_xfer_callback,
-                                   data,
-                                   xfer_callback,
-                                   data);
+    gnome_vfs_async_xfer (&data->handle,
+                          data->src_uri_list,
+                          data->dest_uri_list,
+                          xferOptions,
+                          GNOME_VFS_XFER_ERROR_MODE_QUERY,
+                          xferOverwriteMode,
+                          XFER_PRIORITY,
+                          (GnomeVFSAsyncXferProgressCallback) async_xfer_callback,
+                          data,
+                          xfer_callback,
+                          data);
 
-    gtk_timeout_add (gnome_cmd_data_get_gui_update_rate (), (GtkFunction)update_xfer_gui_func, data);
+    g_timeout_add (gnome_cmd_data.gui_update_rate, (GSourceFunc) update_xfer_gui_func, data);
 }
 
 
@@ -504,9 +506,9 @@ gnome_cmd_xfer_tmp_download_multiple (GList *src_uri_list,
 
     data = create_xfer_data (xferOptions, src_uri_list, dest_uri_list,
                              NULL, NULL, NULL,
-                             (GFunc)on_completed_func, on_completed_data);
+                             (GFunc) on_completed_func, on_completed_data);
 
-    data->win = GNOME_CMD_XFER_PROGRESS_WIN (gnome_cmd_xfer_progress_win_new ());
+    data->win = GNOME_CMD_XFER_PROGRESS_WIN (gnome_cmd_xfer_progress_win_new (g_list_length (src_uri_list)));
     gtk_window_set_title (GTK_WINDOW (data->win), _("downloading to /tmp"));
     gtk_widget_show (GTK_WIDGET (data->win));
 
@@ -519,12 +521,10 @@ gnome_cmd_xfer_tmp_download_multiple (GList *src_uri_list,
                                    GNOME_VFS_XFER_ERROR_MODE_ABORT,
                                    xferOverwriteMode,
                                    XFER_PRIORITY,
-                                   (GnomeVFSAsyncXferProgressCallback)async_xfer_callback,
+                                   (GnomeVFSAsyncXferProgressCallback) async_xfer_callback,
                                    data,
                                    xfer_callback,
                                    data);
 
-    gtk_timeout_add (gnome_cmd_data_get_gui_update_rate (),
-                     (GtkFunction)update_xfer_gui_func,
-                     data);
+    g_timeout_add (gnome_cmd_data.gui_update_rate, (GSourceFunc) update_xfer_gui_func, data);
 }
