@@ -5,6 +5,7 @@
     Part of
         GNOME Commander - A GNOME based file manager
         Copyright (C) 2001-2006 Marcus Bjurman
+        Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -42,6 +43,9 @@
 #include "gnome-cmd-file.h"
 #include "utils.h"
 
+using namespace std;
+
+
 #define DEFAULT_TAB_SIZE          8
 #define DEFAULT_WRAP_MODE      TRUE
 #define DEFAULT_FIXED_LIMIT      80
@@ -51,19 +55,19 @@
 
 
 /* Class Private Data */
-struct _GViewerPrivate
+struct GViewerPrivate
 {
-    GtkWidget           *tscrollbox;
-    TextRender          *textr;
+    GtkWidget         *tscrollbox;
+    TextRender        *textr;
 
-    GtkWidget           *iscrollbox;
-    ImageRender         *imgr;
-    gboolean            img_initialized;
+    GtkWidget         *iscrollbox;
+    ImageRender       *imgr;
+    gboolean          img_initialized;
 
-    GtkWidget           *last_client;
+    GtkWidget         *last_client;
 
-    gchar               *filename;
-    VIEWERDISPLAYMODE   dispmode;
+    gchar             *filename;
+    VIEWERDISPLAYMODE dispmode;
 
 };
 
@@ -92,7 +96,7 @@ static void gviewer_auto_detect_display_mode(GViewer *obj);
     public functions
     (defined in the header file)
 *****************************************/
-GtkType gviewer_get_type (void)
+GtkType gviewer_get_type ()
 {
     static GtkType type = 0;
     if (type == 0)
@@ -116,7 +120,7 @@ GtkType gviewer_get_type (void)
 }
 
 
-GtkWidget *gviewer_new (void)
+GtkWidget *gviewer_new ()
 {
     GViewer *w = (GViewer *) gtk_type_new (gviewer_get_type ());
 
@@ -133,7 +137,7 @@ static void gviewer_class_init (GViewerClass *klass)
     object_class->destroy = gviewer_destroy;
 
     gviewer_signals[STATUS_LINE_CHANGED] =
-        gtk_signal_new ("status_line_changed",
+        gtk_signal_new ("status-line-changed",
             GTK_RUN_LAST,
             G_OBJECT_CLASS_TYPE (object_class),
             GTK_SIGNAL_OFFSET (GViewerClass, status_line_changed),
@@ -166,7 +170,7 @@ static void gviewer_init (GViewer *w)
     text_render_attach_external_v_range(w->priv->textr, scroll_box_get_v_range(SCROLL_BOX(w->priv->tscrollbox)));
     scroll_box_set_client (SCROLL_BOX(w->priv->tscrollbox), GTK_WIDGET (w->priv->textr));
     gtk_widget_show (GTK_WIDGET (w->priv->textr));
-    gtk_widget_show(w->priv->tscrollbox);
+    gtk_widget_show (w->priv->tscrollbox);
     g_object_ref (G_OBJECT (w->priv->tscrollbox));
 
     w->priv->imgr  = (ImageRender *) image_render_new();
@@ -189,8 +193,8 @@ static void gviewer_init (GViewer *w)
 
     g_signal_connect (G_OBJECT (w), "destroy-event", G_CALLBACK (gviewer_destroy), (gpointer) w);
 
-    g_signal_connect (G_OBJECT (w->priv->textr), "text_status_changed", G_CALLBACK (gviewer_text_status_update), (gpointer) w);
-    g_signal_connect (G_OBJECT (w->priv->imgr), "image_status_changed", G_CALLBACK (gviewer_image_status_update), (gpointer) w);
+    g_signal_connect (G_OBJECT (w->priv->textr), "text-status-changed", G_CALLBACK (gviewer_text_status_update), (gpointer) w);
+    g_signal_connect (G_OBJECT (w->priv->imgr), "image-status-changed", G_CALLBACK (gviewer_image_status_update), (gpointer) w);
 }
 
 
@@ -205,8 +209,8 @@ static void gviewer_text_status_update(TextRender *obj, TextRenderStatus *status
 
     g_snprintf(temp, sizeof (temp),
                _("Position: %lu of %lu\tColumn: %d\t%s"),
-               (unsigned long)status->current_offset,
-               (unsigned long)status->size,
+               (unsigned long) status->current_offset,
+               (unsigned long) status->size,
                status->column,
                status->wrap_mode?_("Wrap"):"");
 
@@ -255,8 +259,8 @@ static void gviewer_destroy (GtkObject *widget)
 
     if (w->priv)
     {
-        g_object_unref(G_OBJECT (w->priv->iscrollbox));
-        g_object_unref(G_OBJECT (w->priv->tscrollbox));
+        g_object_unref (G_OBJECT (w->priv->iscrollbox));
+        g_object_unref (G_OBJECT (w->priv->tscrollbox));
 
         g_free (w->priv);
         w->priv = NULL;
@@ -304,7 +308,7 @@ void gviewer_auto_detect_display_mode(GViewer *obj)
 
     obj->priv->dispmode = DISP_MODE_TEXT_FIXED;
 
-    if (obj->priv->textr==NULL)
+    if (!obj->priv->textr)
         return;
 
     ViewerFileOps *fops = text_render_get_file_ops(obj->priv->textr);
@@ -341,17 +345,17 @@ void gviewer_set_display_mode(GViewer *obj, VIEWERDISPLAYMODE mode)
     {
         case DISP_MODE_TEXT_FIXED:
             client = obj->priv->tscrollbox;
-            text_render_set_display_mode(obj->priv->textr, TR_DISP_MODE_TEXT);
+            text_render_set_display_mode (obj->priv->textr, TR_DISP_MODE_TEXT);
             break;
 
         case DISP_MODE_BINARY:
             client = obj->priv->tscrollbox;
-            text_render_set_display_mode(obj->priv->textr, TR_DISP_MODE_BINARY);
+            text_render_set_display_mode (obj->priv->textr, TR_DISP_MODE_BINARY);
             break;
 
         case DISP_MODE_HEXDUMP:
             client = obj->priv->tscrollbox;
-            text_render_set_display_mode(obj->priv->textr, TR_DISP_MODE_HEXDUMP);
+            text_render_set_display_mode (obj->priv->textr, TR_DISP_MODE_HEXDUMP);
             break;
 
         case DISP_MODE_IMAGE:
@@ -362,9 +366,9 @@ void gviewer_set_display_mode(GViewer *obj, VIEWERDISPLAYMODE mode)
     if (client != obj->priv->last_client)
     {
         if (obj->priv->last_client)
-            gtk_container_remove(GTK_CONTAINER(obj), obj->priv->last_client);
+            gtk_container_remove (GTK_CONTAINER(obj), obj->priv->last_client);
 
-        gtk_widget_grab_focus(GTK_WIDGET (client));
+        gtk_widget_grab_focus (GTK_WIDGET (client));
         gtk_table_attach (GTK_TABLE (obj), client , 0, 1, 0, 1,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
@@ -382,7 +386,7 @@ void gviewer_set_display_mode(GViewer *obj, VIEWERDISPLAYMODE mode)
                 break;
         }
 
-        gtk_widget_show(client);
+        gtk_widget_show (client);
         obj->priv->last_client = client;
     }
 }
